import pyautogui
import logging
import seaborn as sns
import matplotlib.pyplot as plt
import pandas as pd
from pynput import mouse
from pynput import keyboard
import numpy as np
from datetime import datetime, timedelta
import os
import threading

# Configure matplotlib to use non-interactive backend
plt.switch_backend('Agg')

# Configure logging
logging.basicConfig(
    filename=f'mouse_clicks_{datetime.now().strftime("%Y%m%d_%H%M%S")}.log',
    level=logging.INFO,
    format='%(asctime)s - %(message)s'
)

# Store coordinates and timing data
coordinates = []
start_time = None
recording = False
total_time = timedelta()
session_folder = None

def create_session_folder():
    folder_name = f'screenshots_{datetime.now().strftime("%Y%m%d_%H%M%S")}'
    os.makedirs(folder_name, exist_ok=True)
    return folder_name

def on_click(x, y, button, pressed):
    global recording, session_folder
    if recording and pressed:
        coordinates.append((x, y))
        logging.info(f'Mouse clicked at coordinates (x={x}, y={y})')
        # Take and save screenshot with cursor
        screenshot = pyautogui.screenshot()
        # Draw cursor on the screenshot
        cursor_img = pyautogui.screenshot()
        plt.figure()
        cursor_draw = plt.imshow(cursor_img)
        plt.plot(x, y, 'ro', markersize=10)  # Add red dot for cursor
        timestamp = datetime.now().strftime("%Y%m%d_%H%M%S_%f")
        plt.axis('off')
        plt.savefig(f'{session_folder}/screenshot_{timestamp}.png', bbox_inches='tight', pad_inches=0)
        plt.close('all')

def on_press(key):
    global recording, start_time, total_time, session_folder
    try:
        if key == keyboard.Key.f9:  # F9 to start/stop recording
            if not recording:
                recording = True
                start_time = datetime.now()
                session_folder = create_session_folder()
                print("Recording started...")
            else:
                recording = False
                if start_time:
                    total_time += datetime.now() - start_time
                create_heatmap()
                print(f"Recording stopped. Total time: {total_time}")
        elif key == keyboard.Key.esc:  # ESC to exit
            return False
    except AttributeError:
        pass

def create_heatmap():
    pass
keyboard_listener = keyboard.Listener(on_press=on_press)
mouse_listener = mouse.Listener(on_click=on_click)

# Start both listeners
keyboard_listener.start()
mouse_listener.start()

print("Press F9 to start/stop recording, ESC to exit")

# Create a main thread event loop
try:
    while keyboard_listener.is_alive():
        keyboard_listener.join(0.1)
except KeyboardInterrupt:
    pass

mouse_listener.stop()
